==> tuia-advert-center-api-2.2.89-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteLandPagePatrolService.java <==
/**
 * Project Name:tuia-core-api<br>
 * File Name:RemoteAdvertBackendService.java<br>
 * Package Name:cn.com.duiba.tuia.core.api.remoteservice<br>
 * Date:2016年8月19日下午4:22:04<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.ResultDto;
import cn.com.duiba.tuia.core.api.dto.advert.AdvertPatrolDto;
import cn.com.duiba.tuia.core.api.dto.rsp.AdvertPageContrastDto;
import cn.com.duiba.tuia.core.api.message.RedisMsgAnnotation;
import cn.com.duiba.tuia.core.api.param.AdvertPatrolRefuseParam;
import cn.com.duiba.tuia.core.api.statistics.domain.GetDailyDataRsp;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.tuia.advert.message.RedisMessageChannel;

import java.util.List;

/**
 * ClassName: RemoteLandPagePatrolService <br/>
 * Function: 落地页巡查. <br/>
 * date: 2017年7月29日 下午4:22:04 <br/>
 *
 * @author youhaijun
 * @version
 * @since JDK 1.8
 */
@AdvancedFeignClient
public interface RemoteLandPagePatrolService {
/**
 *  * @Description: selectVaildList 查询需要巡查的广告计划列表
     *
     * @Param: []
     * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.util.List<cn.com.duiba.tuia.core.api.dto.rsp.AdvertPageContrastDto>>
     * @throws:
     * @author: youhaijun
     * @Date:   2017/7/27
     */
    DubboResult<List<AdvertPageContrastDto>> selectVaildList();

    /***
         * @Description: batchSaveConstrast 保存对比记录
         *  没有id则新增记录 否则更新已有的对比记录
         * @Param: [recordList]
         * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.lang.Integer>
         * @throws:
         * @author: youhaijun
         * @Date:   2017/7/27
         */
    DubboResult<Integer> saveConstrast(AdvertPageContrastDto record);

    /***
         * @Description: updateConstrast 更新某一条对比记录
         *
         * @Param: [recordList]
         * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.lang.Integer>
         * @throws:
         * @author: youhaijun
         * @Date:   2017/7/27
         */
    DubboResult<Integer> updateConstrast(AdvertPageContrastDto recordList);

    List<AdvertPageContrastDto> selectAllList();

    /**
     * 获取需要巡查的广告落地页列表
     * @return
     *
     */
    List<AdvertPatrolDto> acquirePatrolList(Long advertId);


    /**
     * 根据广告主、行业标签、落地页标签属性获取需要巡查的广告落地页列表
     */
    List<AdvertPatrolDto> acquireNewPatrolList(String companyName, String matchTagNum, String tagNumResoureType);

    /**
     * 落地页巡查审核拒绝接口
     *
     * @param param 落地页审核拒绝参数
     * @return
     */
    ResultDto<Boolean> refuseAdvertCheck(AdvertPatrolRefuseParam param);

    /**
     *获取当日发券pv,当日消耗等数据
     */
    List<GetDailyDataRsp> getCurrentTimeData(String curDate, List<Long> advertIds);

    /**
     * 更新广告列表的启用状态.
     *
     * @param advertiserId 广告主ID
     * @param status 启用状态(0：暂停， 1启用)
     * @return 修改状态成功的数量
     */
    void updateEnableStatusForAdverts(Long advertiserId, int status);


}

==> tuia-advert-center-api-2.4.70-sources.jar: cn/com/duiba/tuia/core/api/remoteservice/RemoteLandPagePatrolService.java <==
/**
 * Project Name:tuia-core-api<br>
 * File Name:RemoteAdvertBackendService.java<br>
 * Package Name:cn.com.duiba.tuia.core.api.remoteservice<br>
 * Date:2016年8月19日下午4:22:04<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.core.api.dto.ResultDto;
import cn.com.duiba.tuia.core.api.dto.advert.AdvertPatrolDto;
import cn.com.duiba.tuia.core.api.dto.rsp.AdvertPageContrastDto;
import cn.com.duiba.tuia.core.api.message.RedisMsgAnnotation;
import cn.com.duiba.tuia.core.api.param.AdvertPatrolRefuseParam;
import cn.com.duiba.tuia.core.api.statistics.domain.GetDailyDataRsp;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.tuia.advert.message.RedisMessageChannel;

import java.util.List;

/**
 * ClassName: RemoteLandPagePatrolService <br/>
 * Function: 落地页巡查. <br/>
 * date: 2017年7月29日 下午4:22:04 <br/>
 *
 * @author youhaijun
 * @version
 * @since JDK 1.8
 */
@AdvancedFeignClient
public interface RemoteLandPagePatrolService {
/**
 *  * @Description: selectVaildList 查询需要巡查的广告计划列表
     *
     * @Param: []
     * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.util.List<cn.com.duiba.tuia.core.api.dto.rsp.AdvertPageContrastDto>>
     * @throws:
     * @author: youhaijun
     * @Date:   2017/7/27
     */
    DubboResult<List<AdvertPageContrastDto>> selectVaildList();

    /***
         * @Description: batchSaveConstrast 保存对比记录
         *  没有id则新增记录 否则更新已有的对比记录
         * @Param: [recordList]
         * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.lang.Integer>
         * @throws:
         * @author: youhaijun
         * @Date:   2017/7/27
         */
    DubboResult<Integer> saveConstrast(AdvertPageContrastDto record);

    /***
         * @Description: updateConstrast 更新某一条对比记录
         *
         * @Param: [recordList]
         * @Return: cn.com.duiba.wolf.dubbo.DubboResult<java.lang.Integer>
         * @throws:
         * @author: youhaijun
         * @Date:   2017/7/27
         */
    DubboResult<Integer> updateConstrast(AdvertPageContrastDto recordList);

    List<AdvertPageContrastDto> selectAllList();

    /**
     * 获取需要巡查的广告落地页列表
     * @return
     *
     */
    List<AdvertPatrolDto> acquirePatrolList(Long advertId);


    /**
     * 根据广告主、行业标签、落地页标签属性获取需要巡查的广告落地页列表
     */
    List<AdvertPatrolDto> acquireNewPatrolList(String companyName, String matchTagNum, String tagNumResoureType);

    /**
     * 落地页巡查审核拒绝接口
     *
     * @param param 落地页审核拒绝参数
     * @return
     */
    ResultDto<Boolean> refuseAdvertCheck(AdvertPatrolRefuseParam param);

    /**
     *获取当日发券pv,当日消耗等数据
     */
    List<GetDailyDataRsp> getCurrentTimeData(String curDate, List<Long> advertIds);

    /**
     * 更新广告列表的启用状态.
     *
     * @param advertiserId 广告主ID
     * @param status 启用状态(0：暂停， 1启用)
     * @return 修改状态成功的数量
     */
    void updateEnableStatusForAdverts(Long advertiserId, int status);

    /**
     *  广告非主链接的落地页审核拒绝
     * @param advertId
     * @param landPageId
     * @param reason
     * @return
     */
    Boolean refuseAdvertPromoteTest(Long advertId,Long landPageId, String reason);


}
